@@ -11,10 +11,10 @@ current_os = device.get_property('OSSO_PRODUCT_RELEASE_NAME')
 
 if current_os == 'OS 2008':
   from hildondesktop import HomeItem
-  from mediabox_widget.core.maemo4 import *
+  from mediaboxwidgetlib.core.maemo4 import *
 elif current_os == 'Maemo 5':
   from hildondesktop import HomePluginItem
-  from mediabox_widget.core.maemo5 import *
+  from mediaboxwidgetlib.core.maemo5 import *
   hd_plugin_type = get_hd_plugin_type()
 
 if __name__ == "__main__":
@@ -30,7 +30,7 @@ if __name__ == "__main__":
     import gobject, gtk
     print 'Loading...'
     from hildondesktop import HomePluginItem
-    from mediabox_widget.core.maemo5 import *
+    from mediaboxwidgetlib.core.maemo5 import *
     hd_plugin_type = get_hd_plugin_type()
     print 'Registering type %s...' % (hd_plugin_type)
     gobject.type_register(hd_plugin_type)
